@@ -28,10 +28,10 @@
 #include "gdkdragprivate.h"
 #include "gdkdropprivate.h"
 #include "gdkeventsprivate.h"
-#include "gdkintl.h"
+#include <glib/gi18n-lib.h>
 #include "gdkkeysprivate.h"
 #include "gdkkeysyms.h"
-#include "gdk-private.h"
+#include "gdkprivate.h"
 
 #include <gobject/gvaluecollector.h>
 
@@ -402,12 +402,15 @@ gdk_event_alloc (GdkEventType event_type,
 
   GdkEvent *event = (GdkEvent *) g_type_create_instance (gdk_event_types[event_type]);
 
-  GDK_NOTE (EVENTS, {
-            char *str = g_enum_to_string (GDK_TYPE_EVENT_TYPE, event_type);
-            g_message ("Allocating a new %s for event type %s",
-                       g_type_name (gdk_event_types[event_type]), str);
-            g_free (str);
-            });
+#ifdef G_ENABLE_DEBUG
+  if (GDK_DEBUG_CHECK (EVENTS))
+    {
+      char *str = g_enum_to_string (GDK_TYPE_EVENT_TYPE, event_type);
+      gdk_debug_message ("Allocating a new %s for event type %s",
+                         g_type_name (gdk_event_types[event_type]), str);
+      g_free (str);
+    }
+#endif
 
   event->event_type = event_type;
   event->surface = surface != NULL ? g_object_ref (surface) : NULL;
@@ -597,7 +600,8 @@ _gdk_event_unqueue (GdkDisplay *display)
 
 /*
  * If the last N events in the event queue are smooth scroll events
- * for the same surface and device, combine them into one.
+ * for the same surface, the same device and the same scroll unit,
+ * combine them into one.
  *
  * We give the remaining event a history with N items, and deltas
  * that are the sum over the history entries.
@@ -611,6 +615,8 @@ gdk_event_queue_handle_scroll_compression (GdkDisplay *display)
   GdkEvent *last_event = NULL;
   GList *scrolls = NULL;
   GArray *history = NULL;
+  GdkScrollUnit scroll_unit = GDK_SCROLL_UNIT_WHEEL;
+  gboolean scroll_unit_defined = FALSE;
   GdkTimeCoord hist;
 
   l = g_queue_peek_tail_link (&display->queued_events);
@@ -618,6 +624,7 @@ gdk_event_queue_handle_scroll_compression (GdkDisplay *display)
   while (l)
     {
       GdkEvent *event = l->data;
+      GdkScrollEvent *scroll_event = (GdkScrollEvent *) event;
 
       if (event->flags & GDK_EVENT_PENDING)
         break;
@@ -634,11 +641,17 @@ gdk_event_queue_handle_scroll_compression (GdkDisplay *display)
           device != event->device)
         break;
 
+      if (scroll_unit_defined &&
+          scroll_unit != scroll_event->unit)
+        break;
+
       if (!last_event)
         last_event = event;
 
       surface = event->surface;
       device = event->device;
+      scroll_unit = scroll_event->unit;
+      scroll_unit_defined = TRUE;
       scrolls = l;
 
       l = l->prev;
@@ -710,7 +723,8 @@ gdk_event_queue_handle_scroll_compression (GdkDisplay *display)
                                     gdk_event_get_modifier_state (old_event),
                                     dx,
                                     dy,
-                                    gdk_scroll_event_is_stop (old_event));
+                                    gdk_scroll_event_is_stop (old_event),
+                                    scroll_unit);
 
       ((GdkScrollEvent *)event)->history = history;
 
@@ -746,15 +760,21 @@ gdk_motion_event_push_history (GdkEvent *event,
 
   memset (&hist, 0, sizeof (GdkTimeCoord));
   hist.time = gdk_event_get_time (history_event);
+
   if (tool)
     {
       hist.flags = gdk_device_tool_get_axes (tool);
       for (i = GDK_AXIS_X; i < GDK_AXIS_LAST; i++)
         gdk_event_get_axis (history_event, i, &hist.axes[i]);
     }
-  else
+
+  /* GdkTimeCoord has no dedicated fields to record event position. For plain
+   * pointer events, and for tools which don't report GDK_AXIS_X/GDK_AXIS_Y
+   * on their own, we surface the position using the X and Y input axes.
+   */
+  if (!(hist.flags & GDK_AXIS_FLAG_X) || !(hist.flags & GDK_AXIS_FLAG_Y))
     {
-      hist.flags = GDK_AXIS_FLAG_X | GDK_AXIS_FLAG_Y;
+      hist.flags |= GDK_AXIS_FLAG_X | GDK_AXIS_FLAG_Y;
       gdk_event_get_position (history_event, &hist.axes[GDK_AXIS_X], &hist.axes[GDK_AXIS_Y]);
     }
 
@@ -903,14 +923,6 @@ gdk_event_get_pointer_emulated (GdkEvent *event)
         return tevent->pointer_emulated;
       }
 
-    case GDK_SCROLL:
-    case GDK_SCROLL_SMOOTH:
-      {
-        GdkScrollEvent *sevent = (GdkScrollEvent *) event;
-
-        return sevent->pointer_emulated;
-      }
-
     default:
       break;
     }
@@ -1505,6 +1517,16 @@ gdk_button_event_get_button (GdkEvent *event)
  * An event related to a key-based device.
  */
 
+static void
+gdk_key_event_finalize (GdkEvent *event)
+{
+  GdkKeyEvent *self = (GdkKeyEvent *) event;
+
+  g_free (self->compose_sequence);
+
+  GDK_EVENT_SUPER (event)->finalize (event);
+}
+
 static GdkModifierType
 gdk_key_event_get_state (GdkEvent *event)
 {
@@ -1516,7 +1538,7 @@ gdk_key_event_get_state (GdkEvent *event)
 static const GdkEventTypeInfo gdk_key_event_info = {
   sizeof (GdkKeyEvent),
   NULL,
-  NULL,
+  gdk_key_event_finalize,
   gdk_key_event_get_state,
   NULL,
   NULL,
@@ -1540,6 +1562,10 @@ GDK_DEFINE_EVENT_TYPE (GdkKeyEvent, gdk_key_event,
  * @is_modifier: whether the event is a modifiers only event
  * @translated: the translated key data for the given @state
  * @no_lock: the translated key data without the given @state
+ * @compose_sequence: (transfer none) (nullable):
+ *   The compose sequence string, either partial or only the
+ *   final composed string, if that can be determined at event
+ *   creation time. Used by selected IM modules.
  *
  * Creates a new `GdkKeyEvent`.
  *
@@ -1554,7 +1580,8 @@ gdk_key_event_new (GdkEventType      type,
                    GdkModifierType   state,
                    gboolean          is_modifier,
                    GdkTranslatedKey *translated,
-                   GdkTranslatedKey *no_lock)
+                   GdkTranslatedKey *no_lock,
+                   char             *compose_sequence)
 {
   g_return_val_if_fail (type == GDK_KEY_PRESS ||
                         type == GDK_KEY_RELEASE, NULL);
@@ -1567,6 +1594,7 @@ gdk_key_event_new (GdkEventType      type,
   self->key_is_modifier = is_modifier;
   self->translated[0] = *translated;
   self->translated[1] = *no_lock;
+  self->compose_sequence = g_strdup (compose_sequence);
 
   return event;
 }
@@ -1597,6 +1625,26 @@ gdk_key_event_get_translated_key (GdkEvent *event,
   return &(self->translated[0]);
 }
 
+/*< private >
+ * gdk_key_event_get_compose_sequence:
+ * @event: (type GdkKeyEvent): a key event
+ *
+ * Extracts the compose sequence string from a key event.
+ *
+ * Returns: (transfer none): the compose sequence string
+ */
+char *
+gdk_key_event_get_compose_sequence (GdkEvent *event)
+{
+  GdkKeyEvent *self = (GdkKeyEvent *) event;
+
+  g_return_val_if_fail (GDK_IS_EVENT (event), 0);
+  g_return_val_if_fail (GDK_IS_EVENT_TYPE (event, GDK_KEY_PRESS) ||
+                        GDK_IS_EVENT_TYPE (event, GDK_KEY_RELEASE), FALSE);
+
+  return self->compose_sequence;
+}
+
 /**
  * gdk_key_event_get_keyval:
  * @event: (type GdkKeyEvent): a key event
@@ -2350,7 +2398,8 @@ gdk_scroll_event_new (GdkSurface      *surface,
                       GdkModifierType  state,
                       double           delta_x,
                       double           delta_y,
-                      gboolean         is_stop)
+                      gboolean         is_stop,
+                      GdkScrollUnit    unit)
 {
   GdkScrollEvent *self = gdk_event_alloc (GDK_SCROLL, surface, device, time);
 
@@ -2360,25 +2409,90 @@ gdk_scroll_event_new (GdkSurface      *surface,
   self->delta_x = delta_x;
   self->delta_y = delta_y;
   self->is_stop = is_stop;
+  self->unit = unit;
 
   return (GdkEvent *) self;
 }
 
 GdkEvent *
 gdk_scroll_event_new_discrete (GdkSurface         *surface,
+                               GdkDevice          *device,
+                               GdkDeviceTool      *tool,
+                               guint32             time,
+                               GdkModifierType     state,
+                               GdkScrollDirection  direction)
+{
+  GdkScrollEvent *self = gdk_event_alloc (GDK_SCROLL, surface, device, time);
+  double delta_x = 0, delta_y = 0;
+
+  switch (direction)
+    {
+    case GDK_SCROLL_UP:
+      delta_y = -1;
+      break;
+    case GDK_SCROLL_DOWN:
+      delta_y = 1;
+      break;
+    case GDK_SCROLL_LEFT:
+      delta_x = -1;
+      break;
+    case GDK_SCROLL_RIGHT:
+      delta_x = 1;
+      break;
+    case GDK_SCROLL_SMOOTH:
+    default:
+      g_assert_not_reached ();
+      break;
+    }
+
+  self->tool = tool != NULL ? g_object_ref (tool) : NULL;
+  self->state = state;
+  self->direction = direction;
+  self->delta_x = delta_x;
+  self->delta_y = delta_y;
+  self->unit = GDK_SCROLL_UNIT_WHEEL;
+
+  return (GdkEvent *) self;
+}
+
+/*< private >
+ * gtk_scroll_event_new_value120:
+ * @surface: the `GdkSurface` of the event
+ * @device: the `GdkDevice` of the event
+ * @tool: (nullable): the tool that generated to event
+ * @time: the event serial
+ * @state: Flags to indicate the state of modifier keys and mouse buttons
+ *   in events.
+ * @direction: scroll direction.
+ * @delta_x: delta on the X axis in the 120.0 scale
+ * @delta_x: delta on the Y axis in the 120.0 scale
+ *
+ * Creates a new discrete GdkScrollEvent for high resolution mouse wheels.
+ *
+ * Both axes send data in fractions of 120 where each multiple of 120
+ * amounts to one logical scroll event. Fractions of 120 indicate a wheel
+ * movement less than one detent.
+ *
+ * Returns: the newly created scroll event
+ */
+GdkEvent *
+gdk_scroll_event_new_value120 (GdkSurface         *surface,
                                GdkDevice          *device,
                                GdkDeviceTool      *tool,
                                guint32             time,
                                GdkModifierType     state,
                                GdkScrollDirection  direction,
-                               gboolean            emulated)
+                               double              delta_x,
+                               double              delta_y)
 {
   GdkScrollEvent *self = gdk_event_alloc (GDK_SCROLL, surface, device, time);
 
   self->tool = tool != NULL ? g_object_ref (tool) : NULL;
   self->state = state;
   self->direction = direction;
-  self->pointer_emulated = emulated;
+  self->delta_x = delta_x / 120.0;
+  self->delta_y = delta_y / 120.0;
+  self->unit = GDK_SCROLL_UNIT_WHEEL;
 
   return (GdkEvent *) self;
 }
@@ -2412,6 +2526,9 @@ gdk_scroll_event_get_direction (GdkEvent *event)
  *
  * The deltas will be zero unless the scroll direction
  * is %GDK_SCROLL_SMOOTH.
+ *
+ * For the representation unit of these deltas, see
+ * [method@Gdk.ScrollEvent.get_unit].
  */
 void
 gdk_scroll_event_get_deltas (GdkEvent *event,
@@ -2454,6 +2571,31 @@ gdk_scroll_event_is_stop (GdkEvent *event)
   return self->is_stop;
 }
 
+/**
+ * gdk_scroll_event_get_unit:
+ * @event: (type GdkScrollEvent): a scroll event.
+ *
+ * Extracts the scroll delta unit of a scroll event.
+ *
+ * The unit will always be %GDK_SCROLL_UNIT_WHEEL if the scroll direction is not
+ * %GDK_SCROLL_SMOOTH.
+ *
+ * Returns: the scroll unit.
+ *
+ * Since: 4.8
+ */
+GdkScrollUnit
+gdk_scroll_event_get_unit (GdkEvent *event)
+{
+  GdkScrollEvent *self = (GdkScrollEvent *) event;
+
+  g_return_val_if_fail (GDK_IS_EVENT (event), GDK_SCROLL_UNIT_WHEEL);
+  g_return_val_if_fail (GDK_IS_EVENT_TYPE (event, GDK_SCROLL),
+                        GDK_SCROLL_UNIT_WHEEL);
+
+  return self->unit;
+}
+
 /* }}} */
 
 /* {{{ GdkTouchpadEvent */
@@ -2589,6 +2731,7 @@ gdk_touchpad_event_new_pinch (GdkSurface              *surface,
 
 GdkEvent *
 gdk_touchpad_event_new_hold (GdkSurface              *surface,
+                             GdkEventSequence        *sequence,
                              GdkDevice               *device,
                              guint32                  time,
                              GdkModifierType          state,
@@ -2601,6 +2744,7 @@ gdk_touchpad_event_new_hold (GdkSurface              *surface,
 
   self->state = state;
   self->phase = phase;
+  self->sequence = sequence;
   self->x = x;
   self->y = y;
   self->n_fingers = n_fingers;
