@@ -76,14 +76,14 @@
 
 #include "gdkglcontextprivate.h"
 
-#include "gdkdebug.h"
+#include "gdkdebugprivate.h"
 #include "gdkdisplayprivate.h"
-#include "gdkintl.h"
+#include <glib/gi18n-lib.h>
 #include "gdkmemoryformatprivate.h"
 #include "gdkmemorytextureprivate.h"
 #include "gdkprofilerprivate.h"
 
-#include "gdk-private.h"
+#include "gdkprivate.h"
 
 #ifdef GDK_WINDOWING_WIN32
 # include "gdk/win32/gdkwin32.h"
@@ -193,7 +193,7 @@ gdk_gl_context_dispose (GObject *gobject)
       if (eglGetCurrentContext () == priv->egl_context)
         eglMakeCurrent(egl_display, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
 
-      GDK_DISPLAY_NOTE (display, OPENGL, g_message ("Destroying EGL context"));
+      GDK_DISPLAY_DEBUG (display, OPENGL, "Destroying EGL context");
 
       eglDestroyContext (egl_display, priv->egl_context);
       priv->egl_context = NULL;
@@ -339,13 +339,13 @@ gdk_gl_context_create_egl_context (GdkGLContext *context,
   context_attribs[i++] = EGL_NONE;
   g_assert (i < N_EGL_ATTRS);
 
-  GDK_DISPLAY_NOTE (display, OPENGL,
-                    g_message ("Creating EGL context version %d.%d (debug:%s, forward:%s, legacy:%s, es:%s)",
-                               major, minor,
-                               debug_bit ? "yes" : "no",
-                               forward_bit ? "yes" : "no",
-                               legacy ? "yes" : "no",
-                               api == GDK_GL_API_GLES ? "yes" : "no"));
+  GDK_DISPLAY_DEBUG (display, OPENGL,
+                     "Creating EGL context version %d.%d (debug:%s, forward:%s, legacy:%s, es:%s)",
+                     major, minor,
+                     debug_bit ? "yes" : "no",
+                     forward_bit ? "yes" : "no",
+                     legacy ? "yes" : "no",
+                     api == GDK_GL_API_GLES ? "yes" : "no");
 
   ctx = eglCreateContext (egl_display,
                           egl_config,
@@ -355,7 +355,7 @@ gdk_gl_context_create_egl_context (GdkGLContext *context,
   if (ctx == NULL)
       return 0;
 
-  GDK_DISPLAY_NOTE (display, OPENGL, g_message ("Created EGL context[%p]", ctx));
+  GDK_DISPLAY_DEBUG (display, OPENGL, "Created EGL context[%p]", ctx);
 
   priv->egl_context = ctx;
   gdk_gl_context_set_is_legacy (context, legacy);
@@ -395,8 +395,8 @@ gdk_gl_context_realize_egl (GdkGLContext  *context,
       return 0;
     }
 
-  prefer_legacy = (GDK_DISPLAY_DEBUG_CHECK (display, GL_LEGACY) ||
-                   (share != NULL && gdk_gl_context_is_legacy (share)));
+  prefer_legacy = (gdk_display_get_debug_flags(display) & GDK_DEBUG_GL_LEGACY) ||
+                   (share != NULL && gdk_gl_context_is_legacy (share));
 
   if (preferred_api == GDK_GL_API_GL)
     {
@@ -1265,7 +1265,7 @@ gdk_gl_context_is_api_allowed (GdkGLContext  *self,
 {
   GdkGLContextPrivate *priv = gdk_gl_context_get_instance_private (self);
 
-  if (GDK_DISPLAY_DEBUG_CHECK (gdk_gl_context_get_display (self), GL_GLES))
+  if (gdk_display_get_debug_flags (gdk_gl_context_get_display (self)) & GDK_DEBUG_GL_GLES)
     {
       if (!(api & GDK_GL_API_GLES))
         {
@@ -1485,9 +1485,7 @@ gdk_gl_context_check_extensions (GdkGLContext *context)
 {
   GdkGLContextPrivate *priv = gdk_gl_context_get_instance_private (context);
   gboolean gl_debug = FALSE;
-#ifdef G_ENABLE_DEBUG
   GdkDisplay *display;
-#endif
 
   if (!gdk_gl_context_is_realized (context))
     return;
@@ -1500,16 +1498,10 @@ gdk_gl_context_check_extensions (GdkGLContext *context)
   priv->has_debug_output = epoxy_has_gl_extension ("GL_ARB_debug_output") ||
                            epoxy_has_gl_extension ("GL_KHR_debug");
 
-#ifdef G_ENABLE_DEBUG
   display = gdk_draw_context_get_display (GDK_DRAW_CONTEXT (context));
-  gl_debug = GDK_DISPLAY_DEBUG_CHECK (display, GL_DEBUG);
-#endif
+  gl_debug = (gdk_display_get_debug_flags (display) & GDK_DEBUG_GL_DEBUG) != 0;
 
-  if (priv->has_debug_output
-#ifndef G_ENABLE_CONSISTENCY_CHECKS
-      && gl_debug
-#endif
-      )
+  if (priv->has_debug_output && gl_debug)
     {
       gdk_gl_context_make_current (context);
       glEnable (GL_DEBUG_OUTPUT);
@@ -1541,20 +1533,20 @@ gdk_gl_context_check_extensions (GdkGLContext *context)
   priv->has_half_float = gdk_gl_context_check_version (context, 3, 0, 3, 0) ||
                          epoxy_has_gl_extension ("OES_vertex_half_float");
 
-  GDK_DISPLAY_NOTE (gdk_draw_context_get_display (GDK_DRAW_CONTEXT (context)), OPENGL,
-    g_message ("%s version: %d.%d (%s)\n"
-                       "* GLSL version: %s\n"
-                       "* Extensions checked:\n"
-                       " - GL_KHR_debug: %s\n"
-                       " - GL_EXT_unpack_subimage: %s\n"
-                       " - OES_vertex_half_float: %s",
-                       gdk_gl_context_get_use_es (context) ? "OpenGL ES" : "OpenGL",
-                       priv->gl_version / 10, priv->gl_version % 10,
-                       priv->is_legacy ? "legacy" : "core",
-                       glGetString (GL_SHADING_LANGUAGE_VERSION),
-                       priv->has_khr_debug ? "yes" : "no",
-                       priv->has_unpack_subimage ? "yes" : "no",
-                       priv->has_half_float ? "yes" : "no"));
+  GDK_DISPLAY_DEBUG (gdk_draw_context_get_display (GDK_DRAW_CONTEXT (context)), OPENGL,
+                     "%s version: %d.%d (%s)\n"
+                     "* GLSL version: %s\n"
+                     "* Extensions checked:\n"
+                     " - GL_KHR_debug: %s\n"
+                     " - GL_EXT_unpack_subimage: %s\n"
+                     " - OES_vertex_half_float: %s",
+                     gdk_gl_context_get_use_es (context) ? "OpenGL ES" : "OpenGL",
+                     priv->gl_version / 10, priv->gl_version % 10,
+                     priv->is_legacy ? "legacy" : "core",
+                     glGetString (GL_SHADING_LANGUAGE_VERSION),
+                     priv->has_khr_debug ? "yes" : "no",
+                     priv->has_unpack_subimage ? "yes" : "no",
+                     priv->has_half_float ? "yes" : "no");
 
   priv->extensions_checked = TRUE;
 }
@@ -1844,8 +1836,8 @@ gdk_gl_backend_use (GdkGLBackend backend_type)
       the_gl_backend_type = backend_type;
       /* This is important!!!11eleven
        * (But really: How do I print a message in 2 categories?) */
-      GDK_NOTE (OPENGL, g_print ("Using OpenGL backend %s\n", gl_backend_names[the_gl_backend_type]));
-      GDK_NOTE (MISC, g_message ("Using Opengl backend %s", gl_backend_names[the_gl_backend_type]));
+      GDK_DEBUG (OPENGL, "Using OpenGL backend %s", gl_backend_names[the_gl_backend_type]);
+      GDK_DEBUG (MISC, "Using OpenGL backend %s", gl_backend_names[the_gl_backend_type]);
     }
 
   g_assert (the_gl_backend_type == backend_type);
