@@ -29,7 +29,7 @@
 
 #include "gdksurface.h"
 
-#include "gdk-private.h"
+#include "gdkprivate.h"
 #include "gdkcontentprovider.h"
 #include "gdkdeviceprivate.h"
 #include "gdkdisplayprivate.h"
@@ -37,7 +37,7 @@
 #include "gdkeventsprivate.h"
 #include "gdkframeclockidleprivate.h"
 #include "gdkglcontextprivate.h"
-#include "gdkintl.h"
+#include <glib/gi18n-lib.h>
 #include "gdkmarshalers.h"
 #include "gdkpopupprivate.h"
 #include "gdkrectangle.h"
@@ -506,9 +506,7 @@ gdk_surface_class_init (GdkSurfaceClass *klass)
    * The mouse pointer for the `GdkSurface`.
    */
   properties[PROP_CURSOR] =
-      g_param_spec_object ("cursor",
-                           P_("Cursor"),
-                           P_("Cursor"),
+      g_param_spec_object ("cursor", NULL, NULL,
                            GDK_TYPE_CURSOR,
                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
@@ -518,9 +516,7 @@ gdk_surface_class_init (GdkSurfaceClass *klass)
    * The `GdkDisplay` connection of the surface.
    */
   properties[PROP_DISPLAY] =
-      g_param_spec_object ("display",
-                           P_("Display"),
-                           P_("Display"),
+      g_param_spec_object ("display", NULL, NULL,
                            GDK_TYPE_DISPLAY,
                            G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
@@ -530,9 +526,7 @@ gdk_surface_class_init (GdkSurfaceClass *klass)
    * The `GdkFrameClock` of the surface.
    */
   properties[PROP_FRAME_CLOCK] =
-      g_param_spec_object ("frame-clock",
-                           P_("Frame Clock"),
-                           P_("Frame Clock"),
+      g_param_spec_object ("frame-clock", NULL, NULL,
                            GDK_TYPE_FRAME_CLOCK,
                            G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
@@ -542,9 +536,7 @@ gdk_surface_class_init (GdkSurfaceClass *klass)
    * Whether the surface is mapped.
    */
   properties[PROP_MAPPED] =
-      g_param_spec_boolean ("mapped",
-                            P_("Mapped"),
-                            P_("Mapped"),
+      g_param_spec_boolean ("mapped", NULL, NULL,
                             FALSE,
                             G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -554,9 +546,7 @@ gdk_surface_class_init (GdkSurfaceClass *klass)
    * The width of the surface in pixels.
    */
   properties[PROP_WIDTH] =
-      g_param_spec_int ("width",
-                        P_("Width"),
-                        P_("Width"),
+      g_param_spec_int ("width", NULL, NULL,
                         0, G_MAXINT, 0,
                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -566,9 +556,7 @@ gdk_surface_class_init (GdkSurfaceClass *klass)
    * The height of the surface, in pixels.
    */
   properties[PROP_HEIGHT] =
-      g_param_spec_int ("height",
-                        P_("Height"),
-                        P_("Height"),
+      g_param_spec_int ("height", NULL, NULL,
                         0, G_MAXINT, 0,
                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -578,9 +566,7 @@ gdk_surface_class_init (GdkSurfaceClass *klass)
    * The scale factor of the surface.
    */
   properties[PROP_SCALE_FACTOR] =
-      g_param_spec_int ("scale-factor",
-                        P_("Scale factor"),
-                        P_("Scale factor"),
+      g_param_spec_int ("scale-factor", NULL, NULL,
                         1, G_MAXINT, 1,
                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -1125,7 +1111,7 @@ gdk_surface_ensure_egl_surface (GdkSurface *self,
       gdk_display_get_egl_config_high_depth (display) != gdk_display_get_egl_config (display))
     {
       gdk_gl_context_clear_current_if_surface (self);
-      eglDestroySurface (gdk_surface_get_display (self), priv->egl_surface);
+      eglDestroySurface (gdk_display_get_egl_display (display), priv->egl_surface);
       priv->egl_surface = NULL;
     }
 
@@ -1234,7 +1220,7 @@ gdk_surface_create_vulkan_context (GdkSurface  *surface,
   g_return_val_if_fail (GDK_IS_SURFACE (surface), NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-  if (GDK_DISPLAY_DEBUG_CHECK (surface->display, VULKAN_DISABLE))
+  if (gdk_display_get_debug_flags (surface->display) & GDK_DEBUG_VULKAN_DISABLE)
     {
       g_set_error_literal (error, GDK_VULKAN_ERROR, GDK_VULKAN_ERROR_NOT_AVAILABLE,
                            _("Vulkan support disabled via GDK_DEBUG"));
@@ -1637,8 +1623,8 @@ gdk_surface_thaw_updates (GdkSurface *surface)
       if (surface->request_motion && surface->request_motion_id == 0)
         {
           surface->request_motion_id =
-            g_idle_add_full (GDK_PRIORITY_REDRAW + 20,
-                             request_motion_cb, surface, NULL);
+            g_idle_add_full (GDK_PRIORITY_REDRAW + 20, request_motion_cb, surface, NULL);
+          gdk_source_set_static_name_by_id (surface->request_motion_id, "[gtk] request_motion_cb");
         }
     }
 }
@@ -2793,9 +2779,8 @@ gdk_surface_queue_set_is_mapped (GdkSurface *surface,
       g_return_if_fail (!surface->set_is_mapped_source_id);
 
       surface->set_is_mapped_source_id =
-        g_idle_add_full (G_PRIORITY_HIGH - 10,
-                         set_is_mapped_idle,
-                         surface, NULL);
+        g_idle_add_full (G_PRIORITY_HIGH - 10, set_is_mapped_idle, surface, NULL);
+      gdk_source_set_static_name_by_id (surface->set_is_mapped_source_id, "[gtk] set_is_mapped_idle");
     }
 }
 
@@ -2815,10 +2800,10 @@ check_autohide (GdkEvent *event)
     // grabs, it will be delivered to the same place as the
     // press, and will cause the auto dismissal to be triggered.
     case GDK_BUTTON_RELEASE:
-#endif
-    case GDK_TOUCH_BEGIN:
     case GDK_TOUCH_END:
     case GDK_TOUCH_CANCEL:
+#endif
+    case GDK_TOUCH_BEGIN:
     case GDK_TOUCHPAD_SWIPE:
     case GDK_TOUCHPAD_PINCH:
       display = gdk_event_get_display (event);
