@@ -28,9 +28,9 @@
 
 #include "gdk/gdkdeviceprivate.h"
 #include "gdk/gdkeventsprivate.h"
-#include "gdk/gdkintl.h"
+#include <glib/gi18n-lib.h>
 #include "gdk/gdkseatprivate.h"
-#include "gdk/gdk-private.h"
+#include "gdk/gdkprivate.h"
 
 #define BIG_STEP 20
 #define SMALL_STEP 1
