@@ -378,7 +378,10 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
 
   existing = CGLGetCurrentContext ();
 
-  gdk_gl_context_get_required_version (context, &major, &minor);
+  gdk_gl_context_get_clipped_version (context,
+                                      GDK_GL_MIN_GL_VERSION_MAJOR,
+                                      GDK_GL_MIN_GL_VERSION_MINOR,
+                                      &major, &minor);
 
   display = gdk_gl_context_get_display (context);
   shared = gdk_display_get_gl_context (display);
@@ -395,10 +398,9 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
         }
     }
 
-  GDK_DISPLAY_NOTE (display,
-                    OPENGL,
-                    g_message ("Creating CGLContextObj (version %d.%d)",
-                               major, minor));
+  GDK_DISPLAY_DEBUG (display, OPENGL,
+                     "Creating CGLContextObj (version %d.%d)",
+                     major, minor);
 
   if (!(pixelFormat = create_pixel_format (major, minor, error)))
     return 0;
@@ -438,11 +440,10 @@ gdk_macos_gl_context_real_realize (GdkGLContext  *context,
       CGLEnable (cgl_context, kCGLCESwapRectangle);
     }
 
-  GDK_DISPLAY_NOTE (display,
-                    OPENGL,
-                    g_message ("Created CGLContextObj@%p using %s",
-                               cgl_context,
-                               get_renderer_name (renderer_id)));
+  GDK_DISPLAY_DEBUG (display, OPENGL,
+                     "Created CGLContextObj@%p using %s",
+                     cgl_context,
+                     get_renderer_name (renderer_id));
 
   self->cgl_context = g_steal_pointer (&cgl_context);
 
