@@ -35,7 +35,7 @@
 
 #include "gdkglcontext.h"
 #include "gdkprofilerprivate.h"
-#include "gdkintl.h"
+#include <glib/gi18n-lib.h>
 #include "gdksurface.h"
 
 #include <cairo.h>
@@ -564,9 +564,9 @@ gdk_win32_gl_context_wgl_realize (GdkGLContext *context,
    * A legacy context cannot be shared with core profile ones, so this means we
    * must stick to a legacy context if the shared context is a legacy context
    */
-  legacy_bit = GDK_DISPLAY_DEBUG_CHECK (display, GL_LEGACY) ?
-               TRUE :
-			   share != NULL && gdk_gl_context_is_legacy (share);
+  legacy_bit = (gdk_display_get_debug_flags (display) & GDK_DEBUG_GL_LEGACY)
+                 ? TRUE
+                 : share != NULL && gdk_gl_context_is_legacy (share);
 
   if (!set_wgl_pixformat_for_hdc (hdc,
                                  &pixel_format,
