@@ -21,12 +21,12 @@
 #include "gdkdeviceprivate.h"
 #include "gdkdevice-xi2-private.h"
 
-#include "gdkintl.h"
+#include <glib/gi18n-lib.h>
 #include "gdkasync.h"
 #include "gdkprivate-x11.h"
 #include "gdkdisplay-x11.h"
 
-#include "gdk-private.h"
+#include "gdkprivate.h"
 
 #include <stdlib.h>
 #include <X11/Xlib.h>
@@ -116,9 +116,7 @@ gdk_x11_device_xi2_class_init (GdkX11DeviceXI2Class *klass)
 
   g_object_class_install_property (object_class,
                                    PROP_DEVICE_ID,
-                                   g_param_spec_int ("device-id",
-                                                     P_("Device ID"),
-                                                     P_("Device identifier"),
+                                   g_param_spec_int ("device-id", NULL, NULL,
                                                      0, G_MAXINT, 0,
                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |
                                                      G_PARAM_STATIC_STRINGS));
@@ -335,11 +333,9 @@ gdk_x11_device_xi2_grab (GdkDevice    *device,
                                                         event_mask,
                                                         &mask.mask_len);
 
-#ifdef G_ENABLE_DEBUG
-  if (GDK_DISPLAY_DEBUG_CHECK (display, NOGRABS))
+  if (gdk_display_get_debug_flags (display) & GDK_DEBUG_NOGRABS)
     status = GrabSuccess;
   else
-#endif
     status = XIGrabDevice (GDK_DISPLAY_XDISPLAY (display),
                            device_xi2->device_id,
                            xwindow,
