@@ -18,129 +18,7 @@
 
 #include "config.h"
 #include "gtkatspipangoprivate.h"
-
-const char *
-pango_style_to_string (PangoStyle style)
-{
-  switch (style)
-    {
-    case PANGO_STYLE_NORMAL:
-      return "normal";
-    case PANGO_STYLE_OBLIQUE:
-      return "oblique";
-    case PANGO_STYLE_ITALIC:
-      return "italic";
-    default:
-      g_assert_not_reached ();
-    }
-}
-
-const char *
-pango_variant_to_string (PangoVariant variant)
-{
-  switch (variant)
-    {
-    case PANGO_VARIANT_NORMAL:
-      return "normal";
-    case PANGO_VARIANT_SMALL_CAPS:
-      return "small_caps";
-    case PANGO_VARIANT_ALL_SMALL_CAPS:
-      return "all_small_caps";
-    case PANGO_VARIANT_PETITE_CAPS:
-      return "petite_caps";
-    case PANGO_VARIANT_ALL_PETITE_CAPS:
-      return "all_petite_caps";
-    case PANGO_VARIANT_UNICASE:
-      return "unicase";
-    case PANGO_VARIANT_TITLE_CAPS:
-      return "title_caps";
-    default:
-      g_assert_not_reached ();
-    }
-}
-
-const char *
-pango_stretch_to_string (PangoStretch stretch)
-{
-  switch (stretch)
-    {
-    case PANGO_STRETCH_ULTRA_CONDENSED:
-      return "ultra_condensed";
-    case PANGO_STRETCH_EXTRA_CONDENSED:
-      return "extra_condensed";
-    case PANGO_STRETCH_CONDENSED:
-      return "condensed";
-    case PANGO_STRETCH_SEMI_CONDENSED:
-      return "semi_condensed";
-    case PANGO_STRETCH_NORMAL:
-      return "normal";
-    case PANGO_STRETCH_SEMI_EXPANDED:
-      return "semi_expanded";
-    case PANGO_STRETCH_EXPANDED:
-      return "expanded";
-    case PANGO_STRETCH_EXTRA_EXPANDED:
-      return "extra_expanded";
-    case PANGO_STRETCH_ULTRA_EXPANDED:
-      return "ultra_expanded";
-    default:
-      g_assert_not_reached ();
-    }
-}
-
-const char *
-pango_underline_to_string (PangoUnderline value)
-{
-  switch (value)
-    {
-    case PANGO_UNDERLINE_NONE:
-      return "none";
-    case PANGO_UNDERLINE_SINGLE:
-    case PANGO_UNDERLINE_SINGLE_LINE:
-      return "single";
-    case PANGO_UNDERLINE_DOUBLE:
-    case PANGO_UNDERLINE_DOUBLE_LINE:
-      return "double";
-    case PANGO_UNDERLINE_LOW:
-      return "low";
-    case PANGO_UNDERLINE_ERROR:
-    case PANGO_UNDERLINE_ERROR_LINE:
-      return "error";
-    default:
-      g_assert_not_reached ();
-    }
-}
-
-const char *
-pango_wrap_mode_to_string (PangoWrapMode mode)
-{
-  switch (mode)
-    {
-    case PANGO_WRAP_WORD:
-      return "word";
-    case PANGO_WRAP_CHAR:
-      return "char";
-    case PANGO_WRAP_WORD_CHAR:
-      return "word-char";
-    default:
-      g_assert_not_reached ();
-    }
-}
-
-static const char *
-pango_align_to_string (PangoAlignment align)
-{
-  switch (align)
-    {
-    case PANGO_ALIGN_LEFT:
-      return "left";
-    case PANGO_ALIGN_CENTER:
-      return "center";
-    case PANGO_ALIGN_RIGHT:
-      return "right";
-    default:
-      g_assert_not_reached ();
-    }
-}
+#include "gtkpango.h"
 
 void
 gtk_pango_get_font_attributes (PangoFontDescription *font,
