@@ -23,7 +23,6 @@
 #include "gtkbuildableprivate.h"
 #include "gtkbuilderscopeprivate.h"
 #include "gtkdebug.h"
-#include "gtkintl.h"
 #include "gtktypebuiltins.h"
 #include "gtkversion.h"
 #include "gdkprofilerprivate.h"
@@ -648,9 +647,8 @@ parse_object (GtkBuildableParseContext  *context,
         {
           data->requested_object_level = data->cur_object_level;
 
-          GTK_NOTE (BUILDER,
-                    g_message ("requested object \"%s\" found at level %d",
-                               object_id, data->requested_object_level));
+          GTK_DEBUG (BUILDER, "requested object \"%s\" found at level %d",
+                              object_id, data->requested_object_level);
 
           data->inside_requested_object = TRUE;
         }
@@ -1409,13 +1407,13 @@ expression_info_construct (GtkBuilder      *builder,
             return NULL;
           }
 
-        if (g_type_is_a (type, G_TYPE_OBJECT))
+        if (g_type_fundamental (type) == G_TYPE_OBJECT)
           {
             GObjectClass *class = g_type_class_ref (type);
             pspec = g_object_class_find_property (class, info->property.property_name);
             g_type_class_unref (class);
           }
-        else if (g_type_is_a (type, G_TYPE_INTERFACE))
+        else if (g_type_fundamental (type) == G_TYPE_INTERFACE)
           {
             GTypeInterface *iface = g_type_default_interface_ref (type);
             pspec = g_object_interface_find_property (iface, info->property.property_name);
@@ -1495,7 +1493,7 @@ parse_signal (ParserData   *data,
       return;
     }
 
-  if (!g_signal_parse_name (name, object_info->type, &id, &detail, FALSE))
+  if (!g_signal_parse_name (name, object_info->type, &id, &detail, TRUE))
     {
       g_set_error (error,
                    GTK_BUILDER_ERROR,
@@ -1848,7 +1846,7 @@ end_element (GtkBuildableParseContext  *context,
 {
   ParserData *data = (ParserData*)user_data;
 
-  GTK_NOTE (BUILDER, g_message ("</%s>", element_name));
+  GTK_DEBUG (BUILDER, "</%s>", element_name);
 
   if (data->subparser && data->subparser->start)
     {
@@ -1930,9 +1928,8 @@ end_element (GtkBuildableParseContext  *context,
       if (data->requested_objects && data->inside_requested_object &&
           (data->cur_object_level == data->requested_object_level))
         {
-          GTK_NOTE (BUILDER,
-                    g_message ("requested object end found at level %d",
-                               data->requested_object_level));
+          GTK_DEBUG (BUILDER, "requested object end found at level %d",
+                              data->requested_object_level);
 
           data->inside_requested_object = FALSE;
         }
