@@ -24,7 +24,6 @@
 #include "gtkcellareabox.h"
 #include "gtkcellrendererpixbuf.h"
 #include "gtkcellrenderertext.h"
-#include "gtkintl.h"
 #include "gtkorientable.h"
 #include "gtkprivate.h"
 #include "gtkwidgetprivate.h"
@@ -195,9 +194,7 @@ gtk_cell_view_class_init (GtkCellViewClass *klass)
    */
   g_object_class_install_property (gobject_class,
 				   PROP_MODEL,
-				   g_param_spec_object  ("model",
-							 P_("CellView model"),
-							 P_("The model for cell view"),
+				   g_param_spec_object  ("model", NULL, NULL,
 							 GTK_TYPE_TREE_MODEL,
 							 GTK_PARAM_READWRITE));
 
@@ -214,9 +211,7 @@ gtk_cell_view_class_init (GtkCellViewClass *klass)
    */
    g_object_class_install_property (gobject_class,
                                     PROP_CELL_AREA,
-                                    g_param_spec_object ("cell-area",
-							 P_("Cell Area"),
-							 P_("The GtkCellArea used to layout cells"),
+                                    g_param_spec_object ("cell-area", NULL, NULL,
 							 GTK_TYPE_CELL_AREA,
 							 GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
@@ -238,10 +233,7 @@ gtk_cell_view_class_init (GtkCellViewClass *klass)
    */
    g_object_class_install_property (gobject_class,
                                     PROP_CELL_AREA_CONTEXT,
-                                    g_param_spec_object ("cell-area-context",
-							 P_("Cell Area Context"),
-							 P_("The GtkCellAreaContext used to "
-							    "compute the geometry of the cell view"),
+                                    g_param_spec_object ("cell-area-context", NULL, NULL,
 							 GTK_TYPE_CELL_AREA_CONTEXT,
 							 GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
@@ -256,10 +248,7 @@ gtk_cell_view_class_init (GtkCellViewClass *klass)
    */
    g_object_class_install_property (gobject_class,
                                     PROP_DRAW_SENSITIVE,
-                                    g_param_spec_boolean ("draw-sensitive",
-							  P_("Draw Sensitive"),
-							  P_("Whether to force cells to be drawn in a "
-							     "sensitive state"),
+                                    g_param_spec_boolean ("draw-sensitive", NULL, NULL,
 							  FALSE,
 							  GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY));
 
@@ -275,10 +264,7 @@ gtk_cell_view_class_init (GtkCellViewClass *klass)
    */
    g_object_class_install_property (gobject_class,
                                     PROP_FIT_MODEL,
-                                    g_param_spec_boolean ("fit-model",
-							  P_("Fit Model"),
-							  P_("Whether to request enough space for "
-							     "every row in the model"),
+                                    g_param_spec_boolean ("fit-model", NULL, NULL,
 							  FALSE,
 							  GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY));
 
