@@ -28,7 +28,6 @@
 
 #include "gtkdropprivate.h"
 #include "gtkeventcontrollerprivate.h"
-#include "gtkintl.h"
 #include "gtkmarshalers.h"
 #include "gtknative.h"
 #include "gtkprivate.h"
@@ -208,6 +207,21 @@ gtk_drop_target_end_drop (GtkDropTarget *self)
   g_object_thaw_notify (G_OBJECT (self));
 }
 
+static GdkDragAction
+make_action_unique (GdkDragAction actions)
+{
+  if (actions & GDK_ACTION_COPY)
+    return GDK_ACTION_COPY;
+
+  if (actions & GDK_ACTION_MOVE)
+    return GDK_ACTION_MOVE;
+
+  if (actions & GDK_ACTION_LINK)
+    return GDK_ACTION_LINK;
+
+  return 0;
+}
+
 static void
 gtk_drop_target_do_drop (GtkDropTarget *self)
 {
@@ -219,7 +233,7 @@ gtk_drop_target_do_drop (GtkDropTarget *self)
   g_signal_emit (self, signals[DROP], 0, &self->value, self->coords.x, self->coords.y, &success);
 
   if (success)
-    gdk_drop_finish (self->drop, gdk_drop_get_actions (self->drop));
+    gdk_drop_finish (self->drop, make_action_unique (self->actions & gdk_drop_get_actions (self->drop)));
   else
     gdk_drop_finish (self->drop, 0);
 
@@ -348,21 +362,6 @@ gtk_drop_target_accept (GtkDropTarget *self,
   return gdk_content_formats_match_gtype (self->formats, gdk_drop_get_formats (drop)) != G_TYPE_INVALID;
 }
 
-static GdkDragAction
-make_action_unique (GdkDragAction actions)
-{
-  if (actions & GDK_ACTION_COPY)
-    return GDK_ACTION_COPY;
-
-  if (actions & GDK_ACTION_MOVE)
-    return GDK_ACTION_MOVE;
-
-  if (actions & GDK_ACTION_LINK)
-    return GDK_ACTION_LINK;
-
-  return 0;
-}
-
 static GdkDragAction
 gtk_drop_target_enter (GtkDropTarget  *self,
                        double          x,
@@ -431,6 +430,12 @@ gtk_drop_target_handle_event (GtkEventController *controller,
 
         graphene_point_init (&self->coords, x, y);
         g_signal_emit (self, signals[MOTION], 0, x, y, &preferred);
+        if (!gdk_drag_action_is_unique (preferred))
+          {
+            g_critical ("Handler for GtkDropTarget::motion on %s %p did not return a unique preferred action",
+                        G_OBJECT_TYPE_NAME (widget), widget);
+            preferred = make_action_unique (preferred);
+          }
         if (preferred &&
             gtk_drop_status (self->drop, self->actions, preferred))
           {
@@ -498,6 +503,12 @@ gtk_drop_target_handle_crossing (GtkEventController    *controller,
       gtk_drop_target_start_drop (self, crossing->drop);
 
       g_signal_emit (self, signals[ENTER], 0, x, y, &preferred);
+        if (!gdk_drag_action_is_unique (preferred))
+          {
+            g_critical ("Handler for GtkDropTarget::enter on %s %p did not return a unique preferred action",
+                        G_OBJECT_TYPE_NAME (widget), widget);
+            preferred = make_action_unique (preferred);
+          }
       if (preferred &&
           gtk_drop_status (self->drop, self->actions, preferred))
         {
@@ -624,9 +635,7 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
    * The `GdkDragActions` that this drop target supports.
    */
   properties[PROP_ACTIONS] =
-       g_param_spec_flags ("actions",
-                           P_("Actions"),
-                           P_("The actions supported by this drop target"),
+       g_param_spec_flags ("actions", NULL, NULL,
                            GDK_TYPE_DRAG_ACTION, 0,
                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -638,9 +647,7 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
    * Deprecated: 4.4: Use [property@Gtk.DropTarget:current-drop] instead
    */
   properties[PROP_DROP] =
-       g_param_spec_object ("drop",
-                            P_("Drop"),
-                            P_("Current drop"),
+       g_param_spec_object ("drop", NULL, NULL,
                             GDK_TYPE_DROP,
                             GTK_PARAM_READABLE | G_PARAM_DEPRECATED);
 
@@ -652,9 +659,7 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
    * Since: 4.4
    */
   properties[PROP_CURRENT_DROP] =
-       g_param_spec_object ("current-drop",
-                            P_("Current drop"),
-                            P_("Current drop"),
+       g_param_spec_object ("current-drop", NULL, NULL,
                             GDK_TYPE_DROP,
                             GTK_PARAM_READABLE);
 
@@ -664,9 +669,7 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
    * The `GdkContentFormats` that determine the supported data formats.
    */
   properties[PROP_FORMATS] =
-       g_param_spec_boxed ("formats",
-                           P_("Formats"),
-                           P_("The supported formats"),
+       g_param_spec_boxed ("formats", NULL, NULL,
                            GDK_TYPE_CONTENT_FORMATS,
                            GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
 
@@ -693,9 +696,7 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
    * so enabling it there is free.
    */
   properties[PROP_PRELOAD] =
-       g_param_spec_boolean ("preload",
-                             P_("Preload"),
-                             P_("Whether drop data should be preloaded while hovering"),
+       g_param_spec_boolean ("preload", NULL, NULL,
                              FALSE,
                              G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -713,9 +714,7 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
    * of available data.
    */
   properties[PROP_VALUE] =
-       g_param_spec_boxed ("value",
-                           P_("Value"),
-                           P_("The value for this drop operation"),
+       g_param_spec_boxed ("value", NULL, NULL,
                            G_TYPE_VALUE,
                            GTK_PARAM_READABLE);
 
