@@ -27,7 +27,7 @@
 #include "gtkfilechooserutils.h"
 #include "gtksizerequest.h"
 #include "gtktypebuiltins.h"
-#include "gtkintl.h"
+#include <glib/gi18n-lib.h>
 #include "gtksettings.h"
 #include "gtktogglebutton.h"
 #include "gtkheaderbar.h"
@@ -380,9 +380,7 @@ gtk_file_chooser_dialog_activate_response (GtkWidget  *widget,
 static void
 gtk_file_chooser_dialog_dispose (GObject *object)
 {
-  GtkFileChooserDialogPrivate *priv = gtk_file_chooser_dialog_get_instance_private (GTK_FILE_CHOOSER_DIALOG (object));
-
-  g_clear_pointer ((GtkWidget **)&priv->widget, gtk_widget_unparent);
+  gtk_widget_dispose_template (GTK_WIDGET (object), GTK_TYPE_FILE_CHOOSER_DIALOG);
 
   G_OBJECT_CLASS (gtk_file_chooser_dialog_parent_class)->dispose (object);
 }
