@@ -120,7 +120,6 @@
 #include "gtktypebuiltins.h"
 #include "gtkprivate.h"
 #include "gtkmain.h"
-#include "gtkintl.h"
 #include "gtkmarshalers.h"
 #include "gtknative.h"
 
@@ -162,7 +161,6 @@ struct _GtkGesturePrivate
   GdkDevice *device;
   GList *group_link;
   guint n_points;
-  guint hold_timeout_id;
   guint recognized : 1;
   guint touchpad : 1;
 };
@@ -175,8 +173,6 @@ static guint signals[N_SIGNALS] = { 0 };
                                       gdk_event_get_event_type (e) == GDK_TOUCHPAD_PINCH || \
                                       gdk_event_get_event_type (e) == GDK_TOUCHPAD_HOLD)
 
-#define HOLD_TIMEOUT_MS 50
-
 GList * _gtk_gesture_get_group_link (GtkGesture *gesture);
 
 G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GtkGesture, gtk_gesture, GTK_TYPE_EVENT_CONTROLLER)
@@ -225,7 +221,6 @@ gtk_gesture_finalize (GObject *object)
 
   gtk_gesture_ungroup (gesture);
   g_list_free (priv->group_link);
-  g_clear_handle_id (&priv->hold_timeout_id, g_source_remove);
 
   g_hash_table_destroy (priv->points);
 
@@ -583,22 +578,6 @@ _gtk_gesture_cancel_all (GtkGesture *gesture)
   _gtk_gesture_check_empty (gesture);
 }
 
-static gboolean
-gtk_gesture_hold_timeout (gpointer user_data)
-{
-  GtkGesture *gesture;
-  GtkGesturePrivate *priv;
-
-  gesture = user_data;
-  priv = gtk_gesture_get_instance_private (gesture);
-
-  if (priv->touchpad)
-    _gtk_gesture_cancel_sequence (gesture, priv->last_sequence);
-
-  priv->hold_timeout_id = 0;
-  return G_SOURCE_REMOVE;
-}
-
 static gboolean
 gesture_within_surface (GtkGesture *gesture,
                         GdkSurface  *surface)
@@ -660,14 +639,10 @@ gtk_gesture_handle_event (GtkEventController *controller,
 
   if (event_type == GDK_BUTTON_PRESS ||
       event_type == GDK_TOUCH_BEGIN ||
-      (event_type == GDK_TOUCHPAD_SWIPE && phase == GDK_TOUCHPAD_GESTURE_PHASE_BEGIN) ||
-      (event_type == GDK_TOUCHPAD_PINCH && phase == GDK_TOUCHPAD_GESTURE_PHASE_BEGIN) ||
-      (event_type == GDK_TOUCHPAD_HOLD && phase == GDK_TOUCHPAD_GESTURE_PHASE_BEGIN))
+      (EVENT_IS_TOUCHPAD_GESTURE (event) &&
+       phase == GDK_TOUCHPAD_GESTURE_PHASE_BEGIN &&
+       gdk_touchpad_event_get_n_fingers (event) == priv->n_points))
     {
-      if ((event_type == GDK_TOUCHPAD_PINCH || event_type == GDK_TOUCHPAD_SWIPE) &&
-          _gtk_gesture_has_matching_touchpoints (gesture))
-        g_clear_handle_id (&priv->hold_timeout_id, g_source_remove);
-
       if (_gtk_gesture_update_point (gesture, event, target, x, y, TRUE))
         {
           gboolean triggered_recognition;
@@ -697,9 +672,9 @@ gtk_gesture_handle_event (GtkEventController *controller,
     }
   else if (event_type == GDK_BUTTON_RELEASE ||
            event_type == GDK_TOUCH_END ||
-           (event_type == GDK_TOUCHPAD_SWIPE && phase == GDK_TOUCHPAD_GESTURE_PHASE_END) ||
-           (event_type == GDK_TOUCHPAD_PINCH && phase == GDK_TOUCHPAD_GESTURE_PHASE_END) ||
-           (event_type == GDK_TOUCHPAD_HOLD && phase == GDK_TOUCHPAD_GESTURE_PHASE_END))
+           (EVENT_IS_TOUCHPAD_GESTURE (event) &&
+            phase == GDK_TOUCHPAD_GESTURE_PHASE_END &&
+            gdk_touchpad_event_get_n_fingers (event) == priv->n_points))
     {
       gboolean was_claimed = FALSE;
 
@@ -719,8 +694,9 @@ gtk_gesture_handle_event (GtkEventController *controller,
     }
   else if (event_type == GDK_MOTION_NOTIFY ||
            event_type == GDK_TOUCH_UPDATE ||
-           (event_type == GDK_TOUCHPAD_SWIPE && phase == GDK_TOUCHPAD_GESTURE_PHASE_UPDATE) ||
-           (event_type == GDK_TOUCHPAD_PINCH && phase == GDK_TOUCHPAD_GESTURE_PHASE_UPDATE))
+           (EVENT_IS_TOUCHPAD_GESTURE (event) &&
+            phase == GDK_TOUCHPAD_GESTURE_PHASE_UPDATE &&
+            gdk_touchpad_event_get_n_fingers (event) == priv->n_points))
     {
       if (event_type == GDK_MOTION_NOTIFY)
         {
@@ -737,21 +713,13 @@ gtk_gesture_handle_event (GtkEventController *controller,
       if (!priv->touchpad)
         _gtk_gesture_cancel_sequence (gesture, sequence);
     }
-  else if ((event_type == GDK_TOUCHPAD_SWIPE && phase == GDK_TOUCHPAD_GESTURE_PHASE_CANCEL) ||
-           (event_type == GDK_TOUCHPAD_PINCH && phase == GDK_TOUCHPAD_GESTURE_PHASE_CANCEL))
+  else if (EVENT_IS_TOUCHPAD_GESTURE (event) &&
+           phase == GDK_TOUCHPAD_GESTURE_PHASE_CANCEL &&
+           gdk_touchpad_event_get_n_fingers (event) == priv->n_points)
     {
       if (priv->touchpad)
         _gtk_gesture_cancel_sequence (gesture, sequence);
     }
-  else if (event_type == GDK_TOUCHPAD_HOLD && phase == GDK_TOUCHPAD_GESTURE_PHASE_CANCEL)
-    {
-      if (priv->hold_timeout_id == 0)
-        {
-          priv->hold_timeout_id = g_timeout_add (HOLD_TIMEOUT_MS,
-                                                 gtk_gesture_hold_timeout,
-                                                 gesture);
-        }
-    }
   else if (event_type == GDK_GRAB_BROKEN)
     {
       GdkSurface *surface;
@@ -777,10 +745,6 @@ gtk_gesture_handle_event (GtkEventController *controller,
 static void
 gtk_gesture_reset (GtkEventController *controller)
 {
-  GtkGesture *gesture = GTK_GESTURE (controller);
-  GtkGesturePrivate *priv = gtk_gesture_get_instance_private (gesture);
-
-  g_clear_handle_id (&priv->hold_timeout_id, g_source_remove);
   _gtk_gesture_cancel_all (GTK_GESTURE (controller));
 }
 
@@ -808,10 +772,7 @@ gtk_gesture_class_init (GtkGestureClass *klass)
    */
   g_object_class_install_property (object_class,
                                    PROP_N_POINTS,
-                                   g_param_spec_uint ("n-points",
-                                                      P_("Number of points"),
-                                                      P_("Number of points needed "
-                                                         "to trigger the gesture"),
+                                   g_param_spec_uint ("n-points", NULL, NULL,
                                                       1, G_MAXUINT, 1,
                                                       GTK_PARAM_READWRITE |
                                                       G_PARAM_CONSTRUCT_ONLY));
@@ -952,7 +913,6 @@ gtk_gesture_init (GtkGesture *gesture)
   priv->points = g_hash_table_new_full (NULL, NULL, NULL,
                                         (GDestroyNotify) free_point_data);
   priv->group_link = g_list_prepend (NULL, gesture);
-  priv->hold_timeout_id = 0;
 }
 
 /**
