@@ -21,7 +21,6 @@
 #include "gtkprivate.h"
 #include "gtktypebuiltins.h"
 #include "gtkmarshalers.h"
-#include "gtkintl.h"
 
 #include "gdk/gdkeventsprivate.h"
 
@@ -334,9 +333,7 @@ gtk_im_context_class_init (GtkIMContextClass *klass)
    * methods to adjust their behaviour.
    */
   properties[PROP_INPUT_PURPOSE] =
-    g_param_spec_enum ("input-purpose",
-                         P_("Purpose"),
-                         P_("Purpose of the text field"),
+    g_param_spec_enum ("input-purpose", NULL, NULL,
                          GTK_TYPE_INPUT_PURPOSE,
                          GTK_INPUT_PURPOSE_FREE_FORM,
                          G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS|G_PARAM_EXPLICIT_NOTIFY);
@@ -348,9 +345,7 @@ gtk_im_context_class_init (GtkIMContextClass *klass)
    * their behaviour.
    */
   properties[PROP_INPUT_HINTS] =
-    g_param_spec_flags ("input-hints",
-                         P_("hints"),
-                         P_("Hints for the text field behaviour"),
+    g_param_spec_flags ("input-hints", NULL, NULL,
                          GTK_TYPE_INPUT_HINTS,
                          GTK_INPUT_HINT_NONE,
                          G_PARAM_READWRITE|G_PARAM_STATIC_STRINGS|G_PARAM_EXPLICIT_NOTIFY);
@@ -612,7 +607,8 @@ gtk_im_context_filter_key (GtkIMContext    *context,
                            state,
                            FALSE, /* FIXME */
                            &translated,
-                           &no_lock);
+                           &no_lock,
+                           NULL);
 
   ret = GTK_IM_CONTEXT_GET_CLASS (context)->filter_keypress (context, key);
 
