@@ -34,6 +34,7 @@
 #include "imm-extra.h"
 
 #include "gdk/gdkkeysyms.h"
+#include "gdk/gdkeventsprivate.h"
 #include "gdk/win32/gdkwin32.h"
 #include "gtk/gtkimmodule.h"
 #include "gtk/gtkstylecontextprivate.h"
@@ -61,9 +62,6 @@ typedef enum {
   GTK_WIN32_IME_FOCUS_BEHAVIOR_FOLLOW,
 } GtkWin32IMEFocusBehavior;
 
-#define IS_DEAD_KEY(k) \
-    ((k) >= GDK_KEY_dead_grave && (k) <= (GDK_KEY_dead_dasia+1))
-
 struct _GtkIMContextIMEPrivate
 {
   /* When pretend_empty_preedit is set to TRUE,
@@ -81,7 +79,6 @@ struct _GtkIMContextIMEPrivate
    *   https://gitlab.gnome.org/GNOME/gtk/commit/c255ba68fc2c918dd84da48a472e7973d3c00b03
    */
   gboolean pretend_empty_preedit;
-  guint32 dead_key_keyval;
   GtkWin32IMEFocusBehavior focus_behavior;
 };
 
@@ -256,7 +253,7 @@ gtk_im_context_ime_set_client_widget (GtkIMContext *context,
 
   if (surface != NULL)
     {
-      HWND hwnd = gdk_win32_surface_get_impl_hwnd (surface);
+      HWND hwnd = gdk_win32_surface_get_handle (surface);
       HIMC himc = ImmGetContext (hwnd);
       if (himc)
         {
@@ -277,134 +274,26 @@ gtk_im_context_ime_set_client_widget (GtkIMContext *context,
   context_ime->client_surface = surface;
 }
 
-static gunichar
-_gtk_im_context_ime_dead_key_unichar (guint    keyval,
-                                      gboolean spacing)
-{
-  switch (keyval)
-    {
-#define CASE(keysym, unicode, spacing_unicode) \
-      case GDK_KEY_dead_##keysym: return (spacing) ? spacing_unicode : unicode;
-
-      CASE (grave, 0x0300, 0x0060);
-      CASE (acute, 0x0301, 0x00b4);
-      CASE (circumflex, 0x0302, 0x005e);
-      CASE (tilde, 0x0303, 0x007e);	/* Also used with perispomeni, 0x342. */
-      CASE (macron, 0x0304, 0x00af);
-      CASE (breve, 0x0306, 0x02d8);
-      CASE (abovedot, 0x0307, 0x02d9);
-      CASE (diaeresis, 0x0308, 0x00a8);
-      CASE (hook, 0x0309, 0);
-      CASE (abovering, 0x030A, 0x02da);
-      CASE (doubleacute, 0x030B, 0x2dd);
-      CASE (caron, 0x030C, 0x02c7);
-      CASE (abovecomma, 0x0313, 0);         /* Equivalent to psili */
-      CASE (abovereversedcomma, 0x0314, 0); /* Equivalent to dasia */
-      CASE (horn, 0x031B, 0);	/* Legacy use for psili, 0x313 (or 0x343). */
-      CASE (belowdot, 0x0323, 0);
-      CASE (cedilla, 0x0327, 0x00b8);
-      CASE (ogonek, 0x0328, 0);	/* Legacy use for dasia, 0x314.*/
-      CASE (iota, 0x0345, 0);
-
-#undef CASE
-    default:
-      return 0;
-    }
-}
-
-static void
-_gtk_im_context_ime_commit_unichar (GtkIMContextIME *context_ime,
-                                    gunichar         c)
-{
-  char utf8[10];
-  int len;
-
-  if (context_ime->priv->dead_key_keyval != 0)
-    {
-      gunichar combining;
-
-      combining =
-        _gtk_im_context_ime_dead_key_unichar (context_ime->priv->dead_key_keyval,
-                                              FALSE);
-      g_unichar_compose (c, combining, &c);
-    }
-
-  len = g_unichar_to_utf8 (c, utf8);
-  utf8[len] = 0;
-
-  g_signal_emit_by_name (context_ime, "commit", utf8);
-  context_ime->priv->dead_key_keyval = 0;
-}
-
 static gboolean
 gtk_im_context_ime_filter_keypress (GtkIMContext *context,
                                     GdkEvent     *event)
 {
   GtkIMContextIME *context_ime;
-  gboolean retval = FALSE;
-  guint32 c;
-  GdkModifierType state, consumed_modifiers, no_text_input_mask;
-  guint keyval;
+  char *compose_sequence = NULL;
 
   g_return_val_if_fail (GTK_IS_IM_CONTEXT_IME (context), FALSE);
   g_return_val_if_fail (event, FALSE);
 
-  if (gdk_event_get_event_type ((GdkEvent *) event) == GDK_KEY_RELEASE)
-    return FALSE;
-
-  no_text_input_mask = GDK_ALT_MASK|GDK_CONTROL_MASK;
-
-  state = gdk_event_get_modifier_state ((GdkEvent *) event);
-  consumed_modifiers = gdk_key_event_get_consumed_modifiers (event);
-
-  if (state & no_text_input_mask & ~consumed_modifiers)
-    return FALSE;
-
   context_ime = GTK_IM_CONTEXT_IME (context);
 
-  if (!context_ime->focus)
-    return FALSE;
-
-  if (!GDK_IS_SURFACE (context_ime->client_surface))
-    return FALSE;
-
-  keyval = gdk_key_event_get_keyval ((GdkEvent *) event);
-
-  if (keyval == GDK_KEY_space &&
-      context_ime->priv->dead_key_keyval != 0)
+  compose_sequence = gdk_key_event_get_compose_sequence (event);
+  if (compose_sequence)
     {
-      c = _gtk_im_context_ime_dead_key_unichar (context_ime->priv->dead_key_keyval, TRUE);
-      context_ime->priv->dead_key_keyval = 0;
-      _gtk_im_context_ime_commit_unichar (context_ime, c);
+      g_signal_emit_by_name (context_ime, "commit", compose_sequence);
       return TRUE;
     }
 
-  c = gdk_keyval_to_unicode (keyval);
-
-  if (c && !g_unichar_iscntrl(c))
-    {
-      _gtk_im_context_ime_commit_unichar (context_ime, c);
-      retval = TRUE;
-    }
-  else if (IS_DEAD_KEY (keyval))
-    {
-      gunichar dead_key;
-
-      dead_key = _gtk_im_context_ime_dead_key_unichar (keyval, FALSE);
-
-      /* Emulate double input of dead keys */
-      if (dead_key && keyval == context_ime->priv->dead_key_keyval)
-        {
-          c = _gtk_im_context_ime_dead_key_unichar (context_ime->priv->dead_key_keyval, TRUE);
-          context_ime->priv->dead_key_keyval = 0;
-          _gtk_im_context_ime_commit_unichar (context_ime, c);
-          _gtk_im_context_ime_commit_unichar (context_ime, c);
-        }
-      else
-        context_ime->priv->dead_key_keyval = keyval;
-    }
-
-  return retval;
+  return FALSE;
 }
 
 
@@ -418,7 +307,7 @@ gtk_im_context_ime_reset (GtkIMContext *context)
   if (!context_ime->client_surface)
     return;
 
-  hwnd = gdk_win32_surface_get_impl_hwnd (context_ime->client_surface);
+  hwnd = gdk_win32_surface_get_handle (context_ime->client_surface);
   himc = ImmGetContext (hwnd);
   if (!himc)
     return;
@@ -453,7 +342,7 @@ get_utf8_preedit_string (GtkIMContextIME *context_ime,
 
   if (!context_ime->client_surface)
     return g_strdup ("");
-  hwnd = gdk_win32_surface_get_impl_hwnd (context_ime->client_surface);
+  hwnd = gdk_win32_surface_get_handle (context_ime->client_surface);
   himc = ImmGetContext (hwnd);
   if (!himc)
     return g_strdup ("");
@@ -512,7 +401,7 @@ get_pango_attr_list (GtkIMContextIME *context_ime, const char *utf8str)
 
   if (!context_ime->client_surface)
     return attrs;
-  hwnd = gdk_win32_surface_get_impl_hwnd (context_ime->client_surface);
+  hwnd = gdk_win32_surface_get_handle (context_ime->client_surface);
   himc = ImmGetContext (hwnd);
   if (!himc)
     return attrs;
@@ -655,7 +544,7 @@ gtk_im_context_ime_focus_in (GtkIMContext *context)
       return;
     }
 
-  hwnd = gdk_win32_surface_get_impl_hwnd (toplevel);
+  hwnd = gdk_win32_surface_get_handle (toplevel);
   himc = ImmGetContext (hwnd);
   if (!himc)
     return;
@@ -741,6 +630,9 @@ gtk_im_context_ime_focus_out (GtkIMContext *context)
 
       case GTK_WIN32_IME_FOCUS_BEHAVIOR_FOLLOW:
         break;
+
+      default:
+        g_assert_not_reached ();
     }
 
   /* remove event filter */
@@ -780,7 +672,7 @@ gtk_im_context_ime_set_cursor_location (GtkIMContext *context,
   if (!context_ime->client_surface)
     return;
 
-  hwnd = gdk_win32_surface_get_impl_hwnd (context_ime->client_surface);
+  hwnd = gdk_win32_surface_get_handle (context_ime->client_surface);
   himc = ImmGetContext (hwnd);
   if (!himc)
     return;
@@ -811,7 +703,7 @@ gtk_im_context_ime_set_use_preedit (GtkIMContext *context,
       HWND hwnd;
       HIMC himc;
 
-      hwnd = gdk_win32_surface_get_impl_hwnd (context_ime->client_surface);
+      hwnd = gdk_win32_surface_get_handle (context_ime->client_surface);
       himc = ImmGetContext (hwnd);
       if (!himc)
         return;
@@ -844,7 +736,7 @@ gtk_im_context_ime_set_preedit_font (GtkIMContext *context)
   if (!(context_ime->client_widget && context_ime->client_surface))
     return;
 
-  hwnd = gdk_win32_surface_get_impl_hwnd (context_ime->client_surface);
+  hwnd = gdk_win32_surface_get_handle (context_ime->client_surface);
   himc = ImmGetContext (hwnd);
   if (!himc)
     return;
@@ -955,10 +847,10 @@ gtk_im_context_ime_message_filter (GdkWin32Display *display,
     return retval;
 
   toplevel = context_ime->client_surface;
-  if (gdk_win32_surface_get_impl_hwnd (toplevel) != msg->hwnd)
+  if (gdk_win32_surface_get_handle (toplevel) != msg->hwnd)
     return retval;
 
-  hwnd = gdk_win32_surface_get_impl_hwnd (context_ime->client_surface);
+  hwnd = gdk_win32_surface_get_handle (context_ime->client_surface);
   himc = ImmGetContext (hwnd);
   if (!himc)
     return retval;
