@@ -59,7 +59,7 @@
 #include "gtkdragsource.h"
 #include "gtkgestureclick.h"
 #include "gtkgesturesingle.h"
-#include "gtkintl.h"
+#include <glib/gi18n-lib.h>
 #include "gtklabel.h"
 #include "gtkmain.h"
 #include "gtkmarshalers.h"
