@@ -22,7 +22,7 @@
 #include "gtkmenutrackeritemprivate.h"
 #include "gtkactionmuxerprivate.h"
 #include "gtkdebug.h"
-#include "gtkintl.h"
+#include "gtkprivate.h"
 
 #include <string.h>
 
@@ -201,13 +201,10 @@ gtk_menu_tracker_item_finalize (GObject *object)
 {
   GtkMenuTrackerItem *self = GTK_MENU_TRACKER_ITEM (object);
 
-  g_free (self->action_namespace);
-  g_free (self->action_and_target);
-
-  if (self->observable)
-    g_object_unref (self->observable);
-
-  g_object_unref (self->item);
+  g_clear_pointer (&self->action_namespace, g_free);
+  g_clear_pointer (&self->action_and_target, g_free);
+  g_clear_object (&self->observable);
+  g_clear_object (&self->item);
 
   G_OBJECT_CLASS (gtk_menu_tracker_item_parent_class)->finalize (object);
 }
@@ -224,29 +221,29 @@ gtk_menu_tracker_item_class_init (GtkMenuTrackerItemClass *class)
   class->finalize = gtk_menu_tracker_item_finalize;
 
   gtk_menu_tracker_item_pspecs[PROP_IS_SEPARATOR] =
-    g_param_spec_boolean ("is-separator", "", "", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_boolean ("is-separator", NULL, NULL, FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_LABEL] =
-    g_param_spec_string ("label", "", "", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_string ("label", NULL, NULL, NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_USE_MARKUP] =
-    g_param_spec_boolean ("use-markup", "", "", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_boolean ("use-markup", NULL, NULL, FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_ICON] =
-    g_param_spec_object ("icon", "", "", G_TYPE_ICON, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_object ("icon", NULL, NULL, G_TYPE_ICON, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_VERB_ICON] =
-    g_param_spec_object ("verb-icon", "", "", G_TYPE_ICON, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_object ("verb-icon", NULL, NULL, G_TYPE_ICON, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_SENSITIVE] =
-    g_param_spec_boolean ("sensitive", "", "", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_boolean ("sensitive", NULL, NULL, FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_ROLE] =
-    g_param_spec_enum ("role", "", "",
+    g_param_spec_enum ("role", NULL, NULL,
                        GTK_TYPE_MENU_TRACKER_ITEM_ROLE, GTK_MENU_TRACKER_ITEM_ROLE_NORMAL,
                        G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_TOGGLED] =
-    g_param_spec_boolean ("toggled", "", "", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_boolean ("toggled", NULL, NULL, FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_ACCEL] =
-    g_param_spec_string ("accel", "", "", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_string ("accel", NULL, NULL, NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_SUBMENU_SHOWN] =
-    g_param_spec_boolean ("submenu-shown", "", "", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_boolean ("submenu-shown", NULL, NULL, FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
   gtk_menu_tracker_item_pspecs[PROP_IS_VISIBLE] =
-    g_param_spec_boolean ("is-visible", "", "", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
+    g_param_spec_boolean ("is-visible", NULL, NULL, FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE);
 
   g_object_class_install_properties (class, N_PROPS, gtk_menu_tracker_item_pspecs);
 }
@@ -305,7 +302,7 @@ gtk_menu_tracker_item_action_added (GtkActionObserver   *observer,
   GtkMenuTrackerItemRole old_role;
   guint n_changed;
 
-  GTK_NOTE(ACTIONS, g_message ("menutracker: action %s added", action_name));
+  GTK_DEBUG (ACTIONS, "menutracker: action %s added", action_name);
 
   old_sensitive = self->sensitive;
   old_toggled = self->toggled;
@@ -319,22 +316,22 @@ gtk_menu_tracker_item_action_added (GtkActionObserver   *observer,
 
   if (!self->can_activate)
     {
-      GTK_NOTE(ACTIONS, g_message ("menutracker: action %s can't be activated due to parameter type mismatch "
-                                   "(parameter type %s, target type %s)",
-                                   action_name,
-                                   parameter_type ? g_variant_type_peek_string (parameter_type) : "NULL",
-                                   action_target ? g_variant_get_type_string (action_target) : "NULL"));
+      GTK_DEBUG (ACTIONS, "menutracker: action %s can't be activated due to parameter type mismatch "
+                          "(parameter type %s, target type %s)",
+                          action_name,
+                          parameter_type ? g_variant_type_peek_string (parameter_type) : "NULL",
+                          action_target ? g_variant_get_type_string (action_target) : "NULL");
 
       if (action_target)
         g_variant_unref (action_target);
       return;
     }
 
-  GTK_NOTE(ACTIONS, g_message ("menutracker: action %s can be activated", action_name));
+  GTK_DEBUG (ACTIONS, "menutracker: action %s can be activated", action_name);
 
   self->sensitive = enabled;
 
-  GTK_NOTE(ACTIONS, g_message ("menutracker: action %s is %s", action_name, enabled ? "enabled" : "disabled"));
+  GTK_DEBUG (ACTIONS, "menutracker: action %s is %s", action_name, enabled ? "enabled" : "disabled");
 
   if (action_target != NULL && state != NULL)
     {
@@ -390,7 +387,7 @@ gtk_menu_tracker_item_action_enabled_changed (GtkActionObserver   *observer,
 {
   GtkMenuTrackerItem *self = GTK_MENU_TRACKER_ITEM (observer);
 
-  GTK_NOTE(ACTIONS, g_message ("menutracker: action %s: enabled changed to %d", action_name, enabled));
+  GTK_DEBUG (ACTIONS, "menutracker: action %s: enabled changed to %d", action_name, enabled);
 
   if (!self->can_activate)
     return;
@@ -415,7 +412,7 @@ gtk_menu_tracker_item_action_state_changed (GtkActionObserver   *observer,
   GVariant *action_target;
   gboolean was_toggled;
 
-  GTK_NOTE(ACTIONS, g_message ("menutracker: action %s: state changed", action_name));
+  GTK_DEBUG (ACTIONS, "menutracker: action %s: state changed", action_name);
 
   if (!self->can_activate)
     return;
@@ -448,7 +445,7 @@ gtk_menu_tracker_item_action_removed (GtkActionObserver   *observer,
   gboolean was_sensitive, was_toggled;
   GtkMenuTrackerItemRole old_role;
 
-  GTK_NOTE(ACTIONS, g_message ("menutracker: action %s was removed", action_name));
+  GTK_DEBUG (ACTIONS, "menutracker: action %s was removed", action_name);
 
   if (!self->can_activate)
     return;
@@ -565,10 +562,14 @@ _gtk_menu_tracker_item_new (GtkActionObservable *observable,
 
       action_name = strrchr (self->action_and_target, '|') + 1;
 
-      GTK_NOTE(ACTIONS,
-               if (!strchr (action_name, '.'))
-                 g_message ("menutracker: action name %s doesn't look like 'app.' or 'win.'; "
-                            "it is unlikely to work", action_name));
+#ifdef G_ENABLE_DEBUG
+      if (GTK_DEBUG_CHECK (ACTIONS))
+        {
+          if (!strchr (action_name, '.'))
+            gdk_debug_message ("menutracker: action name %s doesn't look like 'app.' or 'win.'; "
+                               "it is unlikely to work", action_name);
+        }
+#endif
 
       state = NULL;
 
@@ -577,12 +578,12 @@ _gtk_menu_tracker_item_new (GtkActionObservable *observable,
 
       if (found)
         {
-          GTK_NOTE(ACTIONS, g_message ("menutracker: action %s existed from the start", action_name));
+          GTK_DEBUG (ACTIONS, "menutracker: action %s existed from the start", action_name);
           gtk_menu_tracker_item_action_added (GTK_ACTION_OBSERVER (self), observable, action_name, parameter_type, enabled, state);
         }
       else
         {
-          GTK_NOTE(ACTIONS, g_message ("menutracker: action %s missing from the start", action_name));
+          GTK_DEBUG (ACTIONS, "menutracker: action %s missing from the start", action_name);
           gtk_menu_tracker_item_update_visibility (self);
         }
 
@@ -873,18 +874,27 @@ gtk_menu_tracker_opener_finalize (GObject *object)
 {
   GtkMenuTrackerOpener *opener = (GtkMenuTrackerOpener *)object;
 
-  gtk_action_observable_unregister_observer (opener->item->observable,
-                                             opener->submenu_action,
-                                             (GtkActionObserver *)opener);
+  if (opener->item != NULL)
+    {
+      GtkMenuTrackerItem *item = g_object_ref (opener->item);
 
-  if (GTK_IS_ACTION_MUXER (opener->item->observable))
-    gtk_action_muxer_change_action_state (GTK_ACTION_MUXER (opener->item->observable),
-                                          opener->submenu_action,
-                                          g_variant_new_boolean (FALSE));
+      g_clear_weak_pointer (&opener->item);
 
-  gtk_menu_tracker_item_set_submenu_shown (opener->item, FALSE);
+      gtk_action_observable_unregister_observer (item->observable,
+                                                 opener->submenu_action,
+                                                 (GtkActionObserver *)opener);
 
-  g_free (opener->submenu_action);
+      if (GTK_IS_ACTION_MUXER (item->observable))
+        gtk_action_muxer_change_action_state (GTK_ACTION_MUXER (item->observable),
+                                              opener->submenu_action,
+                                              g_variant_new_boolean (FALSE));
+
+      gtk_menu_tracker_item_set_submenu_shown (item, FALSE);
+
+      g_object_unref (item);
+    }
+
+  g_clear_pointer (&opener->submenu_action, g_free);
 
   G_OBJECT_CLASS (gtk_menu_tracker_opener_parent_class)->finalize (object);
 }
@@ -995,7 +1005,8 @@ gtk_menu_tracker_opener_new (GtkMenuTrackerItem *item,
   opener = g_object_new (gtk_menu_tracker_opener_get_type (), NULL);
 
   opener->first_time = TRUE;
-  opener->item = item;
+
+  g_set_weak_pointer (&opener->item, item);
 
   if (item->action_namespace)
     opener->submenu_action = g_strjoin (".", item->action_namespace, submenu_action, NULL);
