@@ -63,7 +63,6 @@
 #include "gtkboxlayout.h"
 #include "gtklabel.h"
 #include "gtkmenubutton.h"
-#include "gtkintl.h"
 #include "gtkprivate.h"
 #include "gtkmarshalers.h"
 #include "gtkgestureclick.h"
@@ -632,9 +631,7 @@ gtk_popover_menu_bar_class_init (GtkPopoverMenuBarClass *klass)
    * The model should only contain submenus as toplevel elements.
    */
   bar_props[PROP_MENU_MODEL] =
-      g_param_spec_object ("menu-model",
-                           P_("Menu model"),
-                           P_("The model from which the bar is made."),
+      g_param_spec_object ("menu-model", NULL, NULL,
                            G_TYPE_MENU_MODEL,
                            GTK_PARAM_READWRITE);
 
