@@ -38,13 +38,14 @@
 #include <windows.h>
 #include <cairo-win32.h>
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 #include "gtkprintoperation-private.h"
 #include "gtkprint-win32.h"
-#include "gtkintl.h"
 #include "gtkwindow.h"
 #include "gtkprivate.h"
 #include "gtkwidgetprivate.h"
 #include "gtknative.h"
+#include "win32/gdkprivate-win32.h"
 
 #define MAX_PAGE_RANGES 20
 #define STATUS_POLLING_TIME 2000
