@@ -35,7 +35,7 @@
 #include "gtkgesturepan.h"
 #include "gtkwidgetprivate.h"
 #include "gtkcenterbox.h"
-#include "gtkintl.h"
+#include <glib/gi18n-lib.h>
 
 /**
  * GtkShortcutsSection:
