@@ -35,7 +35,7 @@
 #include "gtkmediafileprivate.h"
 #include "gtkimmoduleprivate.h"
 
-#include "gdk/gdkdebug.h"
+#include "gdk/gdkdebugprivate.h"
 
 #ifdef GDK_WINDOWING_X11
 #include "x11/gdkx.h"
@@ -45,12 +45,12 @@
 
 #ifdef GDK_WINDOWING_WIN32
 #include "win32/gdkwin32.h"
+#include "gdkglcontextprivate.h"
 #include <epoxy/wgl.h>
-#endif
-
 #ifdef GDK_WIN32_ENABLE_EGL
 #include <epoxy/egl.h>
 #endif
+#endif
 
 #ifdef GDK_WINDOWING_MACOS
 #include "macos/gdkmacos.h"
@@ -387,7 +387,8 @@ init_gl (GtkInspectorGeneral *gen)
   else
 #endif
 #ifdef GDK_WINDOWING_WIN32
-  if (GDK_IS_WIN32_DISPLAY (gen->display))
+  if (GDK_IS_WIN32_DISPLAY (gen->display) &&
+      gdk_gl_backend_can_be_used (GDK_GL_WGL, NULL))
     {
       int gl_version;
       char *version;
@@ -1086,8 +1087,6 @@ gtk_inspector_general_dispose (GObject *object)
   GtkInspectorGeneral *gen = GTK_INSPECTOR_GENERAL (object);
   GList *list, *l;
 
-  g_clear_pointer (&gen->swin, gtk_widget_unparent);
-
   g_signal_handlers_disconnect_by_func (gen->display, G_CALLBACK (seat_added), gen);
   g_signal_handlers_disconnect_by_func (gen->display, G_CALLBACK (seat_removed), gen);
   g_signal_handlers_disconnect_by_func (gen->display, G_CALLBACK (populate_display_notify_cb), gen);
@@ -1098,6 +1097,8 @@ gtk_inspector_general_dispose (GObject *object)
     disconnect_seat (gen, GDK_SEAT (l->data));
   g_list_free (list);
 
+  gtk_widget_dispose_template (GTK_WIDGET (gen), GTK_TYPE_INSPECTOR_GENERAL);
+
   G_OBJECT_CLASS (gtk_inspector_general_parent_class)->dispose (object);
 }
 
