@@ -29,6 +29,7 @@
 
 #include "gtkadjustment.h"
 #include "gtkbox.h"
+#include "gtkbutton.h"
 #include "gtkdropdown.h"
 #include "gtkcssproviderprivate.h"
 #include "gtkdebug.h"
@@ -59,7 +60,7 @@
 #include "broadway/gdkbroadway.h"
 #endif
 
-#include "gdk/gdkdebug.h"
+#include "gdk/gdkdebugprivate.h"
 
 #define EPSILON               1e-10
 
@@ -96,7 +97,6 @@ struct _GtkInspectorVisual
 
   GtkWidget *misc_box;
   GtkWidget *touchscreen_switch;
-  GtkWidget *software_gl_switch;
 
   GtkInspectorOverlay *fps_overlay;
   GtkInspectorOverlay *updates_overlay;
@@ -1020,51 +1020,21 @@ row_activated (GtkListBox         *box,
       GtkSwitch *sw = GTK_SWITCH (vis->touchscreen_switch);
       gtk_switch_set_active (sw, !gtk_switch_get_active (sw));
     }
-  else if (gtk_widget_is_ancestor (vis->software_gl_switch, GTK_WIDGET (row)))
-    {
-      GtkSwitch *sw = GTK_SWITCH (vis->software_gl_switch);
-      gtk_switch_set_active (sw, !gtk_switch_get_active (sw));
-    }
 }
 
 static void
 init_gl (GtkInspectorVisual *vis)
 {
-  GdkDebugFlags flags = gdk_display_get_debug_flags (vis->display);
-
-  gtk_switch_set_active (GTK_SWITCH (vis->software_gl_switch), flags & GDK_DEBUG_GL_SOFTWARE);
-
-  if (flags & GDK_DEBUG_GL_DISABLE)
-    {
-      GtkWidget *row;
-
-      gtk_widget_set_sensitive (vis->software_gl_switch, FALSE);
-      row = gtk_widget_get_ancestor (vis->software_gl_switch, GTK_TYPE_LIST_BOX_ROW);
-      gtk_widget_set_tooltip_text (row, _("GL rendering is disabled"));
-    }
 }
 
 static void
-update_gl_flag (GtkSwitch     *sw,
-                GdkDebugFlags  flag,
-                GtkInspectorVisual *vis)
+inspect_inspector (GtkButton          *button,
+                   GtkInspectorVisual *vis)
 {
-  GdkDebugFlags flags = gdk_display_get_debug_flags (vis->display);
+  GtkWidget *inspector_window;
 
-  if (gtk_switch_get_active (sw))
-    flags |= flag;
-  else
-    flags &= ~flag;
-
-  gdk_display_set_debug_flags (vis->display, flags);
-}
-
-static void
-software_gl_activate (GtkSwitch *sw,
-                      GParamSpec *pspec,
-                      GtkInspectorVisual *vis)
-{
-  update_gl_flag (sw, GDK_DEBUG_GL_SOFTWARE, vis);
+  inspector_window = gtk_inspector_window_get (gtk_widget_get_display (GTK_WIDGET (button)));
+  gtk_window_present (GTK_WINDOW (inspector_window));
 }
 
 static void
@@ -1080,12 +1050,12 @@ gtk_inspector_visual_constructed (GObject *object)
 
   G_OBJECT_CLASS (gtk_inspector_visual_parent_class)->constructed (object);
 
-   g_signal_connect (vis->visual_box, "keynav-failed", G_CALLBACK (keynav_failed), vis);
-   g_signal_connect (vis->debug_box, "keynav-failed", G_CALLBACK (keynav_failed), vis);
-   g_signal_connect (vis->misc_box, "keynav-failed", G_CALLBACK (keynav_failed), vis);
-   g_signal_connect (vis->visual_box, "row-activated", G_CALLBACK (row_activated), vis);
-   g_signal_connect (vis->debug_box, "row-activated", G_CALLBACK (row_activated), vis);
-   g_signal_connect (vis->misc_box, "row-activated", G_CALLBACK (row_activated), vis);
+  g_signal_connect (vis->visual_box, "keynav-failed", G_CALLBACK (keynav_failed), vis);
+  g_signal_connect (vis->debug_box, "keynav-failed", G_CALLBACK (keynav_failed), vis);
+  g_signal_connect (vis->misc_box, "keynav-failed", G_CALLBACK (keynav_failed), vis);
+  g_signal_connect (vis->visual_box, "row-activated", G_CALLBACK (row_activated), vis);
+  g_signal_connect (vis->debug_box, "row-activated", G_CALLBACK (row_activated), vis);
+  g_signal_connect (vis->misc_box, "row-activated", G_CALLBACK (row_activated), vis);
 }
 
 static void
@@ -1123,7 +1093,7 @@ gtk_inspector_visual_dispose (GObject *object)
 {
   GtkInspectorVisual *vis = GTK_INSPECTOR_VISUAL (object);
 
-  g_clear_pointer (&vis->swin, gtk_widget_unparent);
+  gtk_widget_dispose_template (GTK_WIDGET (vis), GTK_TYPE_INSPECTOR_VISUAL);
 
   G_OBJECT_CLASS (gtk_inspector_visual_parent_class)->dispose (object);
 }
@@ -1159,7 +1129,6 @@ gtk_inspector_visual_class_init (GtkInspectorVisualClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorVisual, debug_box);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorVisual, font_button);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorVisual, misc_box);
-  gtk_widget_class_bind_template_child (widget_class, GtkInspectorVisual, software_gl_switch);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorVisual, font_scale_entry);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorVisual, font_scale_adjustment);
   gtk_widget_class_bind_template_child (widget_class, GtkInspectorVisual, fps_switch);
@@ -1176,7 +1145,7 @@ gtk_inspector_visual_class_init (GtkInspectorVisualClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, baselines_activate);
   gtk_widget_class_bind_template_callback (widget_class, layout_activate);
   gtk_widget_class_bind_template_callback (widget_class, focus_activate);
-  gtk_widget_class_bind_template_callback (widget_class, software_gl_activate);
+  gtk_widget_class_bind_template_callback (widget_class, inspect_inspector);
 
   gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BIN_LAYOUT);
 }
